@@ -15,31 +15,40 @@
 
 import pathlib
 import shutil
-import subprocess
+
+from pymedphys._streamlit.server import start
 
 HERE = pathlib.Path(__file__).parent.resolve()
 STREAMLIT_CONTENT_DIR = HERE.joinpath("_streamlit")
 
 
-def fill_streamlit_credentials():
-    streamlit_config_dir = pathlib.Path.home().joinpath(".streamlit")
+def main(args):
+    """Boot up the pymedphys GUI"""
+    _fill_streamlit_credentials()
+
+    streamlit_script_path = str(HERE.joinpath("_app.py"))
+
+    if args.port:
+        config = {"server.port": args.port}
+    else:
+        config = {}
+
+    start.start_streamlit_server(streamlit_script_path, config)
+
+
+def _fill_streamlit_credentials():
+    streamlit_config_file = pathlib.Path.home().joinpath(
+        ".streamlit", "credentials.toml"
+    )
+    if streamlit_config_file.exists():
+        return
+
+    streamlit_config_dir = streamlit_config_file.parent
     streamlit_config_dir.mkdir(exist_ok=True)
 
-    template_streamlit_credentials_file = STREAMLIT_CONTENT_DIR.joinpath(
-        "credentials.toml"
-    )
-    new_credential_file = streamlit_config_dir.joinpath("credentials.toml")
+    template_streamlit_config_file = STREAMLIT_CONTENT_DIR.joinpath("credentials.toml")
 
     try:
-        shutil.copy2(template_streamlit_credentials_file, new_credential_file)
+        shutil.copy2(template_streamlit_config_file, streamlit_config_file)
     except FileExistsError:
         pass
-
-
-def main(_):
-    fill_streamlit_credentials()
-
-    streamlit_script_path = str(STREAMLIT_CONTENT_DIR.joinpath("index.py"))
-    subprocess.check_call(
-        " ".join(["streamlit", "run", streamlit_script_path]), shell=True
-    )
