@@ -14,6 +14,7 @@
 
 
 import base64
+import functools
 import os
 import pathlib
 import subprocess
@@ -25,21 +26,14 @@ from pymedphys._imports import numpy as np
 from pymedphys._imports import pandas as pd
 from pymedphys._imports import plt
 from pymedphys._imports import streamlit as st
-from pymedphys._imports import timeago
+from pymedphys._imports import streamlit_ace, timeago, tomlkit
 
 import pymedphys
-from pymedphys._streamlit.apps.metersetmap import (
-    _config,
-    _dicom,
-    _icom,
-    _monaco,
-    _mosaiq,
-    _trf,
-)
-from pymedphys._streamlit.utilities import config as st_config
 from pymedphys._streamlit.utilities import exceptions as _exceptions
 from pymedphys._streamlit.utilities import misc as st_misc
 
+from . import _config, _dicom, _icom, _monaco, _mosaiq, _trf
+
 DATA_OPTION_LABELS = {
     "monaco": "Monaco tel.1 filepath",
     "dicom": "DICOM RTPlan file upload",
@@ -76,7 +70,11 @@ def get_most_recent_file_and_print(linac_id, filepaths):
     if not isinstance(filepaths, list):
         raise ValueError("Filepaths needs to be a list")
 
-    latest_filepath = max(filepaths, key=os.path.getmtime)
+    try:
+        latest_filepath = max(filepaths, key=os.path.getmtime)
+    except ValueError:
+        st.sidebar.markdown(f"{linac_id}: `Never`")
+        return
 
     most_recent = datetime.fromtimestamp(os.path.getmtime(latest_filepath))
     now = datetime.now()
@@ -100,13 +98,15 @@ def trf_status(linac_id, backup_directory):
     get_most_recent_file_and_print(linac_id, filepaths)
 
 
-def show_status_indicators():
+def show_status_indicators(config):
     if st.sidebar.button("Check status of iCOM and backups"):
         try:
             linac_icom_live_stream_directories = (
-                _config.get_icom_live_stream_directories()
+                _config.get_icom_live_stream_directories(config)
+            )
+            linac_indexed_backups_directory = _config.get_indexed_backups_directory(
+                config
             )
-            linac_indexed_backups_directory = _config.get_indexed_backups_directory()
         except KeyError:
             st.sidebar.write(
                 _exceptions.ConfigMissing(
@@ -175,10 +175,10 @@ def get_input_data_ui(
     data_method_map,
     default_method,
     key_namespace,
-    advanced_mode_local,
+    advanced_mode,
     **previous_results,
 ):
-    if advanced_mode_local:
+    if advanced_mode:
         data_method_options = list(data_method_map.keys())
         data_method = st.selectbox(
             "Data Input Method",
@@ -191,7 +191,7 @@ def get_input_data_ui(
 
     results = data_method_map[data_method](  # type: ignore
         key_namespace=key_namespace,
-        advanced_mode_local=advanced_mode_local,
+        advanced_mode=advanced_mode,
         **previous_results,
     )
 
@@ -352,9 +352,7 @@ def calculate_gamma(reference_metersetmap, evaluation_metersetmap, gamma_options
     return gamma
 
 
-def advanced_debugging():
-    config = st_config.get_config()
-
+def advanced_debugging(config):
     st.sidebar.markdown("# Advanced Debugging")
     if st.sidebar.button("Compare Baseline to Output Directory"):
         st.write(
@@ -423,8 +421,8 @@ def run_calculation(
     reference_results,
     evaluation_results,
     gamma_options,
-    escan_directory,
-    png_output_directory,
+    escan_directory: pathlib.Path,
+    png_output_directory: pathlib.Path,
 ):
     st.write("Calculating Reference MetersetMap...")
     reference_metersetmap = calculate_batch_metersetmap(reference_results["deliveries"])
@@ -450,7 +448,7 @@ def run_calculation(
         escan_directory.joinpath(f"{output_base_filename}.pdf").resolve()
     )
     png_record_directory = png_output_directory.joinpath(output_base_filename)
-    png_record_directory.mkdir(exist_ok=True)
+    png_record_directory.mkdir(exist_ok=True, parents=True)
     png_filepath = str(png_record_directory.joinpath("report.png").resolve())
 
     try:
@@ -556,13 +554,32 @@ def convert_png_to_pdf(png_filepath, pdf_filepath):
 def main():
     st.write(
         """
-        # MetersetMap comparison tool
-
         Tool to compare the MetersetMap between planned and delivery.
         """
     )
 
-    config = st_config.get_config()
+    st.sidebar.markdown(
+        """
+        # Configuration Choice
+        """
+    )
+
+    config_options = list(_config.CONFIG_OPTIONS.keys())
+
+    try:
+        _config.get_config(config_options[0])
+    except FileNotFoundError:
+        config_options.pop(0)
+
+    config_mode = st.sidebar.radio("Config Mode", options=config_options)
+    config = _config.get_config(config_mode)
+
+    show_config = st.sidebar.checkbox("Show/edit config", False)
+    if show_config:
+        st.write("## Configuration")
+        config = tomlkit.loads(
+            streamlit_ace.st_ace(value=tomlkit.dumps(config), language="toml")
+        )
 
     st.sidebar.markdown(
         """
@@ -597,7 +614,7 @@ def main():
         """
     )
 
-    show_status_indicators()
+    show_status_indicators(config)
 
     st.sidebar.markdown(
         """
@@ -608,7 +625,7 @@ def main():
     )
     advanced_mode = st.sidebar.checkbox("Run in Advanced Mode")
 
-    gamma_options = _config.get_gamma_options(advanced_mode)
+    gamma_options = _config.get_gamma_options(config, advanced_mode)
 
     data_option_functions = {
         "monaco": _monaco.monaco_input_method,
@@ -627,7 +644,9 @@ def main():
 
     data_method_map = {}
     for method in available_data_methods:
-        data_method_map[DATA_OPTION_LABELS[method]] = data_option_functions[method]
+        data_method_map[DATA_OPTION_LABELS[method]] = functools.partial(
+            data_option_functions[method], config=config
+        )
 
     st.write(
         """
@@ -635,34 +654,42 @@ def main():
         """
     )
 
-    st.write(
-        """
-        ### Reference
-        """
-    )
+    st.write("---")
 
-    reference_results = get_input_data_ui(
-        overview_updater_map,
-        data_method_map,
-        default_reference,
-        "reference",
-        advanced_mode,
-    )
+    ref_col, eval_col = st.beta_columns(2)
 
-    st.write(
-        """
-        ### Evaluation
-        """
-    )
+    with ref_col:
+        st.write(
+            """
+            ### Reference
+            """
+        )
 
-    evaluation_results = get_input_data_ui(
-        overview_updater_map,
-        data_method_map,
-        default_evaluation,
-        "evaluation",
-        advanced_mode,
-        **reference_results,
-    )
+        reference_results = get_input_data_ui(
+            overview_updater_map,
+            data_method_map,
+            default_reference,
+            "reference",
+            advanced_mode,
+        )
+
+    with eval_col:
+        st.write(
+            """
+            ### Evaluation
+            """
+        )
+
+        evaluation_results = get_input_data_ui(
+            overview_updater_map,
+            data_method_map,
+            default_evaluation,
+            "evaluation",
+            advanced_mode,
+            **reference_results,
+        )
+
+    st.write("---")
 
     st.write(
         """
@@ -683,7 +710,11 @@ def main():
         default_site = reference_results.get("site", None)
 
     _, escan_directory = st_misc.get_site_and_directory(
-        "eScan Site", "escan", default=default_site, key="escan_export_site_picker"
+        config,
+        "eScan Site",
+        "escan",
+        default=default_site,
+        key="escan_export_site_picker",
     )
 
     escan_directory = pathlib.Path(os.path.expanduser(escan_directory)).resolve()
@@ -745,4 +776,4 @@ def main():
         )
 
     if advanced_mode:
-        advanced_debugging()
+        advanced_debugging(config)
