@@ -16,25 +16,17 @@
 import functools
 import os
 import pathlib
+from typing import Callable, Dict
 
 from pymedphys._imports import streamlit as st
+from typing_extensions import Literal
 
-import pymedphys
 from pymedphys import _config as pmp_config
 
 
-def download_and_extract_demo_data(cwd):
-    pymedphys.zip_data_paths("metersetmap-gui-e2e-data.zip", extract_directory=cwd)
-
-
 @st.cache
-def get_config():
-    try:
-        result = pmp_config.get_config()
-    except FileNotFoundError:
-        cwd = pathlib.Path.cwd()
-        download_and_extract_demo_data(cwd)
-        result = pmp_config.get_config(cwd.joinpath("pymedphys-gui-demo"))
+def get_config(path=None):
+    result = pmp_config.get_config(path=path)
 
     return result
 
@@ -51,11 +43,25 @@ def get_export_directory_from_site_config(site_config, export_directory):
     )
 
 
-@st.cache
-def get_site_directories():
-    config = get_config()
+DirectoryConfigOptions = Literal[
+    "monaco", "escan", "anonymised_monaco", "iviewdb", "icom"
+]
 
-    site_directory_functions = {
+DirectoriesForSite = Dict[DirectoryConfigOptions, pathlib.Path]
+
+
+@st.cache
+def get_site_directories(config) -> Dict[str, DirectoriesForSite]:
+    """A config wrapper that retrieves a dictionary that maps site to directories.
+
+    Returns
+    -------
+    site_directories
+        A dictionary indexed by site. Each site has within it a
+        dictionary that is indexed by directory type.
+
+    """
+    site_directory_functions: Dict[DirectoryConfigOptions, Callable] = {
         "monaco": get_monaco_from_site_config,
         "escan": functools.partial(
             get_export_directory_from_site_config, export_directory="escan"
@@ -66,9 +72,12 @@ def get_site_directories():
         "iviewdb": functools.partial(
             get_export_directory_from_site_config, export_directory="iviewdb"
         ),
+        "icom": functools.partial(
+            get_export_directory_from_site_config, export_directory="icom"
+        ),
     }
 
-    site_directories = {}
+    site_directories: Dict[str, DirectoriesForSite] = {}
     for site in config["site"]:
         site_name = site["name"]
         site_directories[site_name] = {}
