@@ -4,7 +4,6 @@
 import os
 
 import pytest
-import pytest_pylint.plugin
 
 SKIPPING_CONFIG = {
     "slow": {
@@ -31,6 +30,12 @@ SKIPPING_CONFIG = {
         "description": "mark test as using pylinac",
         "skip_otherwise": False,
     },
+    "mosaiqdb": {
+        "options": ["--run-only-mosaiqdb", "--mosaiqdb"],
+        "help": "run only the tests that use mosaiq db",
+        "description": "mark test as using mosaiq db",
+        "skip_otherwise": True,
+    },
 }
 
 
@@ -74,12 +79,6 @@ def pytest_collection_modifyitems(config, items):
                 if key not in item.keywords:
                     item.add_marker(skip)
 
-    if config.getoption("--pylint"):
-        skip = pytest.mark.skip(reason="Don't run tests when running pylint")
-        for item in items:
-            if not isinstance(item, pytest_pylint.plugin.PyLintItem):
-                item.add_marker(skip)
-
 
 def pytest_ignore_collect(path, config):  # pylint: disable = unused-argument
     """return True to prevent considering this path for collection.
@@ -95,9 +94,15 @@ def pytest_ignore_collect(path, config):  # pylint: disable = unused-argument
         (len(relative_path_list) > 1 and relative_path_list[0] == "examples")
         or "node_modules" in relative_path_list
         or "site-packages" in relative_path_list
+        or "_build" in relative_path_list
         or ("_bundle" in relative_path_list and "python" in relative_path_list)
         or (
             config.getoption("--doctest-modules")
-            and ("_streamlit" in relative_path_list or "tests" in relative_path_list)
+            and (
+                "_streamlit" in relative_path_list
+                or "tests" in relative_path_list
+                or "_imports" in relative_path_list
+                or "_experimental" in relative_path_list
+            )
         )
     )
