@@ -1,5 +1,5 @@
 from ._vendor.deprecated import deprecated as _deprecated
-from .metersetmap import WARNING_MESSAGE  # pylint: disable = unused-import
+from .metersetmap import WARNING_MESSAGE as _WARNING_MESSAGE
 from .metersetmap import calculate as _calculate
 from .metersetmap import display as _display
 from .metersetmap import grid as _grid
@@ -18,3 +18,5 @@ _grid.__name__ = "pymedphys.mudensity.grid"
 grid = _deprecated(reason="This has been replaced with `pymedphys.metersetmap.grid`")(
     _grid
 )
+
+WARNING_MESSAGE = _WARNING_MESSAGE
