@@ -11,14 +11,9 @@ from os.path import join as pjoin
 from shutil import copyfile
 from uuid import uuid4
 
-import pytest
-
-import pydicom
-import pydicom.datadict
-import pydicom.dataset
-import pydicom.filereader
-import pydicom.tag
+from pymedphys._imports import pydicom, pytest
 
+import pymedphys._utilities.test as pmp_test_utils
 from pymedphys._data import download
 from pymedphys._dicom import create
 from pymedphys._dicom.anonymise import (
@@ -49,27 +44,6 @@ TEST_ANON_BASENAME_DICT = {
     "RIBT.not_quite_anonymised.dcm": "RIBT.1.2.392.200036.9123.100.30.310.200.12.1.20191125110540243000_Anonymised.dcm",
 }
 
-VR_NON_ANONYMOUS_REPLACEMENT_VALUE_DICT = {
-    "AE": "AnAETitle",
-    "AS": "1Y",
-    "CS": "SMITH",
-    "DA": "20190429",
-    "DS": "11111111.9",
-    "DT": "20190429000700.000000",
-    "LO": "Smith",
-    "LT": "LongText",
-    "OB": (2).to_bytes(2, "little"),
-    "OB or OW": (2).to_bytes(2, "little"),
-    "OW": (2).to_bytes(2, "little"),
-    "PN": "Smith",
-    "SH": "Smith",
-    "SQ": [pydicom.dataset.Dataset(), pydicom.dataset.Dataset()],
-    "ST": "Smith",
-    "TM": "000700.000000",
-    "UI": "1118",
-    "US": 11111,
-}
-
 
 @functools.lru_cache()
 def get_rtplan_test_file_path():
@@ -150,6 +124,28 @@ def _check_is_anonymised_dataset_file_and_dir(
 def _get_non_anonymous_replacement_value(keyword):
     """Get an appropriate dummy non-anonymised value for a DICOM element based
     on its value representation (VR)"""
+
+    VR_NON_ANONYMOUS_REPLACEMENT_VALUE_DICT = {
+        "AE": "AnAETitle",
+        "AS": "1Y",
+        "CS": "SMITH",
+        "DA": "20190429",
+        "DS": "11111111.9",
+        "DT": "20190429000700.000000",
+        "LO": "Smith",
+        "LT": "LongText",
+        "OB": (2).to_bytes(2, "little"),
+        "OB or OW": (2).to_bytes(2, "little"),
+        "OW": (2).to_bytes(2, "little"),
+        "PN": "Smith",
+        "SH": "Smith",
+        "SQ": [pydicom.dataset.Dataset(), pydicom.dataset.Dataset()],
+        "ST": "Smith",
+        "TM": "000700.000000",
+        "UI": "1118",
+        "US": 11111,
+    }
+
     vr = get_baseline_keyword_vr_dict()[keyword]
     return VR_NON_ANONYMOUS_REPLACEMENT_VALUE_DICT[vr]
 
@@ -458,6 +454,9 @@ def test_anonymise_cli(tmp_path):
 
 def _test_anonymise_cli_for_file(tmp_path, test_file_path):
     temp_filepath = str(tmp_path / "test.dcm")
+
+    dicom_anonymise_cli = pmp_test_utils.get_pymedphys_dicom_cli() + ["anonymise"]
+
     try:
         logging.info("CLI test on %s", test_file_path)
 
@@ -468,7 +467,7 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
         assert not is_anonymised_file(temp_filepath)
         assert not exists(temp_anon_filepath)
 
-        anon_file_command = "pymedphys dicom anonymise".split() + [temp_filepath]
+        anon_file_command = dicom_anonymise_cli + [temp_filepath]
         try:
             subprocess.check_call(anon_file_command)
             assert is_anonymised_file(temp_anon_filepath)
@@ -482,9 +481,7 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
         expected_anon_filepath = label_dicom_filepath_as_anonymised(temp_filepath)
         assert not exists(expected_anon_filepath)
 
-        anon_file_pres_command = "pymedphys dicom anonymise -f".split() + [
-            temp_filepath
-        ]
+        anon_file_pres_command = dicom_anonymise_cli + ["-f", temp_filepath]
         try:
             subprocess.check_call(anon_file_pres_command)
             assert is_anonymised_file(expected_anon_filepath)
@@ -498,9 +495,7 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
 
         temp_cleared_anon_filepath = str(tmp_path / test_anon_basename)
 
-        anon_file_clear_command = "pymedphys dicom anonymise -c".split() + [
-            temp_filepath
-        ]
+        anon_file_clear_command = dicom_anonymise_cli + ["-c", temp_filepath]
         try:
             subprocess.check_call(anon_file_clear_command)
             assert is_anonymised_file(temp_cleared_anon_filepath)
@@ -513,11 +508,11 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
         assert not is_anonymised_file(temp_filepath)
         assert not exists(temp_anon_filepath)
 
-        anon_file_keep_command = (
-            "pymedphys dicom anonymise".split()
-            + [temp_filepath]
-            + "-k PatientName".split()
-        )
+        anon_file_keep_command = dicom_anonymise_cli + [
+            temp_filepath,
+            "-k",
+            "PatientName",
+        ]
         try:
             subprocess.check_call(anon_file_keep_command)
             assert not is_anonymised_file(temp_anon_filepath)
@@ -532,9 +527,7 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
         assert not is_anonymised_file(temp_filepath)
         assert not exists(temp_anon_filepath)
 
-        anon_file_private_command = "pymedphys dicom anonymise -p".split() + [
-            temp_filepath
-        ]
+        anon_file_private_command = dicom_anonymise_cli + ["-p", temp_filepath]
         try:
             subprocess.check_call(anon_file_private_command)
             assert not is_anonymised_file(temp_anon_filepath)
@@ -550,7 +543,7 @@ def _test_anonymise_cli_for_file(tmp_path, test_file_path):
         assert not is_anonymised_directory(tmp_path)
         assert not exists(temp_anon_filepath)
 
-        anon_dir_command = "pymedphys dicom anonymise".split() + [str(tmp_path)]
+        anon_dir_command = dicom_anonymise_cli + [str(tmp_path)]
         try:
             subprocess.check_call(anon_dir_command)
             assert is_anonymised_file(temp_anon_filepath)
