@@ -17,12 +17,10 @@ import os
 import subprocess
 import uuid
 
-import pytest
-
-import numpy as np
-
-import pydicom
+from pymedphys._imports import numpy as np
+from pymedphys._imports import pydicom, pytest
 
+import pymedphys._utilities.test as pmp_test_utils
 from pymedphys._dicom.create import dicom_dataset_from_dict
 from pymedphys._dicom.header import (
     RED_adjustment_map_from_structure_names,
@@ -81,7 +79,8 @@ def test_adjust_machine_name():
     assert adjusted_ds != original_ds
     assert adjusted_ds == expected_ds
 
-    command = "pymedphys dicom adjust-machine-name".split() + [
+    command = pmp_test_utils.get_pymedphys_dicom_cli() + [
+        "adjust-machine-name",
         ORIGINAL_DICOM_FILENAME,
         ADJUSTED_DICOM_FILENAME,
         new_name,
@@ -197,7 +196,8 @@ def test_electron_density_append():
     excess_adjustment_map_flat = np.concatenate(excess_adjustment_map_as_list).tolist()
 
     command = (
-        "pymedphys dicom adjust-RED -i ".split()
+        pmp_test_utils.get_pymedphys_dicom_cli()
+        + ["adjust-RED", "-i"]
         + [ORIGINAL_DICOM_FILENAME, ADJUSTED_DICOM_FILENAME]
         + excess_adjustment_map_flat
     )
@@ -273,7 +273,8 @@ def test_structure_name_based_RED_append():
     assert adjusted_ds != original_ds
     assert str(expected_ds) == str(adjusted_ds)
 
-    command = "pymedphys dicom adjust-RED-by-structure-name".split() + [
+    command = pmp_test_utils.get_pymedphys_dicom_cli() + [
+        "adjust-RED-by-structure-name",
         ORIGINAL_DICOM_FILENAME,
         ADJUSTED_DICOM_FILENAME,
     ]
