@@ -25,22 +25,6 @@ describe("st.file_uploader", () => {
 
   beforeEach(() => {
     cy.start("pseudonymise")
-
-    // The next command allow downloads in Electron, Chrome, and Edge
-    // without any users popups or file save dialogs.
-    if (Cypress.browser.name !== 'firefox') {
-      // since this call returns a promise, must tell Cypress to wait
-      // for it to be resolved
-      cy.wrap(
-        Cypress.automation('remote:debugger:protocol',
-          {
-            command: 'Page.setDownloadBehavior',
-            params: { behavior: 'allow', downloadPath: downloadsFolder },
-          }),
-        { log: false }
-      )
-    }
-
   });
 
   it('downloads remote zip', {}, () => {
@@ -72,10 +56,11 @@ describe("st.file_uploader", () => {
   })
   it("shows widget correctly", () => {
 
-    cy.get(".stFileUploader")
+    // From https://github.com/streamlit/streamlit/blob/a03d3b9ae3c43a63b149dd590f8f6cf17ec917dd/e2e/specs/st_file_uploader.spec.js#L33
+    cy.get("[data-testid='stFileUploader']")
       .first()
       .should("exist");
-    cy.get(".stFileUploader label")
+    cy.get("[data-testid='stFileUploader'] label")
       .first()
       .should("have.text", "Files to pseudonymise, refresh page after downloading zip(s)");
 
@@ -97,7 +82,7 @@ describe("st.file_uploader", () => {
   // });
 
   it("hides deprecation warning", () => {
-    cy.get(".stFileUploader")
+    cy.get("[data-testid='stFileUploader']")
       .last()
       .parent()
       .prev()
@@ -145,7 +130,8 @@ describe("st.file_uploader", () => {
         //   { fileContent: file2, fileName: fileName2, mimeType: "application/octet-stream" }
       ];
 
-      cy.get(".fileUploadDropzone")
+      // From https://github.com/streamlit/streamlit/blob/a03d3b9ae3c43a63b149dd590f8f6cf17ec917dd/e2e/specs/st_file_uploader.spec.js#L69
+      cy.get("[data-testid='stFileUploadDropzone']")
         .eq(0)
         .attachFile(files[0], {
           force: true,
@@ -196,7 +182,7 @@ describe("st.file_uploader", () => {
           { fileContent: file2, fileName: fileName2, mimeType: "application/octet-stream" }
         ];
 
-        cy.get(".fileUploadDropzone")
+        cy.get("[data-testid='stFileUploadDropzone']")
           .eq(0)
           .attachFile(files[0], {
             force: true,
