@@ -30,23 +30,32 @@
 
 import 'cypress-file-upload';
 
+function getBaseUrl() {
+  let url = Cypress.env('PYMEDPHYS_GUI_URL')
+  if (url === undefined) {
+    url = "http://localhost:8501"
+  }
+
+  return url
+}
 
 Cypress.Commands.add('compute', () => {
   let start = new Date().getTime();
-  cy.get("#ReportStatus", { timeout: 4000 }).should($el => {
+  cy.get(".StatusWidget-enter-done", { timeout: 4000 }).should($el => {
     let now = new Date().getTime();
     if (now - start < 1000) {
-      expect($el).to.be.visible
+      expect($el).to.exist
     } else {
-      expect($el).to.not.be.visible
+      expect($el).to.not.exist
     }
   })
 
-  cy.get("#ReportStatus", { timeout: 120000 }).should("not.be.visible")
+  cy.get(".StatusWidget-enter-done", { timeout: 120000 }).should("not.exist", { timeout: 120000 })
 })
 
 Cypress.Commands.add('textMatch', (label, length, result) => {
-  let text = cy.get(`.stMarkdown p:contains(${label})`).should("have.length", length)
+  // From https://github.com/streamlit/streamlit/blob/a03d3b9ae3c43a63b149dd590f8f6cf17ec917dd/e2e/specs/st_markdown.spec.js#L24
+  let text = cy.get(`.element-container .stMarkdown p:contains(${label})`).should("have.length", length)
   if (result !== null) {
     text.find('code').each(($el) => {
       return cy.wrap($el).should("have.text", result)
@@ -55,17 +64,22 @@ Cypress.Commands.add('textMatch', (label, length, result) => {
 })
 
 Cypress.Commands.add('start', (app) => {
-  cy.visit('http://localhost:8501')
+  let url = getBaseUrl()
+  cy.visit(url)
 
   Cypress.Cookies.defaults({
     preserve: ["_xsrf"]
   });
 
-  cy.visit(`http://localhost:8501/?app=${app}`);
+  cy.visit(`${url}/?app=${app}`);
   cy.compute()
-  cy.get(".decoration").invoke("css", "display", "none");
-})
 
+  // From https://github.com/streamlit/streamlit/blob/a03d3b9ae3c43a63b149dd590f8f6cf17ec917dd/e2e/specs/component_template.spec.js#L41-L42
+  // Make the ribbon decoration line disappear
+  cy.get("[data-testid='stDecoration']").invoke("css", "display", "none");
+
+  cy.compute()
+})
 
 Cypress.Commands.add('scroll', () => {
   cy.get(".main").scrollTo("bottomLeft");
@@ -79,3 +93,14 @@ Cypress.Commands.add('finalScreenshot', () => {
   cy.scroll()
   cy.screenshot()
 })
+
+Cypress.Commands.add('radio', (title, item) => {
+  cy
+    .contains(title)
+    .parent()
+    .contains(item)
+    .find("input")
+    .first()
+    .click({ force: true });
+  cy.compute()
+})
