@@ -12,27 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pathlib
-import subprocess
 
-import pytest
+from pymedphys._imports import pytest
 
 import pymedphys
-from pymedphys._utilities.test import process
 
-HERE = pathlib.Path(__file__).parent.resolve()
+from . import utilities
 
 
 @pytest.mark.cypress
 def test_cypress():
-    pymedphys.zip_data_paths("metersetmap-gui-e2e-data.zip", extract_directory=HERE)
+    pymedphys.zip_data_paths(
+        "metersetmap-gui-e2e-data.zip", extract_directory=utilities.HERE
+    )
 
     pymedphys.zip_data_paths(
         "dummy-ct-and-struct.zip",
-        extract_directory=HERE.joinpath("cypress", "fixtures"),
+        extract_directory=utilities.HERE.joinpath("cypress", "fixtures"),
     )
 
-    with process("poetry run pymedphys gui", cwd=HERE, shell=True) as _:
-        subprocess.check_call("yarn", cwd=HERE, shell=True)
-
-        subprocess.check_call("yarn cypress run", cwd=HERE, shell=True)
+    utilities.run_test_commands_with_gui_process(["yarn", "yarn cypress run"])
