@@ -12,10 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pytest
+from pymedphys._imports import numpy as np
+from pymedphys._imports import plt, pytest
 
-import matplotlib.pyplot as plt
-import numpy as np
+from pymedphys._mocks.profiles import create_rectangular_field_function
 
 from pymedphys._experimental.film import (
     align_images,
@@ -23,7 +23,6 @@ from pymedphys._experimental.film import (
     interpolated_rotation,
     shift_and_rotate,
 )
-from pymedphys._mocks.profiles import create_rectangular_field_function
 
 
 def test_shift_alignment():
