@@ -12,12 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import numpy as np
+from pymedphys._imports import numpy as np
+
+from pymedphys._utilities.constants import A_LEAF_TYPE, AGILITY
 
 from pymedphys._experimental.paulking.collequivalent import (
     mlc_equivalent_square_fs as equivalent_square,
 )
-from pymedphys._utilities.constants import A_LEAF_TYPE, AGILITY
 
 # import pytest
 
