@@ -20,9 +20,10 @@
 
 import os
 
-import numpy as np
+from pymedphys._imports import numpy as np
 
 from pymedphys._data import download
+
 from pymedphys._experimental.paulking.profile import Profile
 
 PROFILER = [
