@@ -13,9 +13,10 @@
 # limitations under the License.
 
 
-import numpy as np
+from pymedphys._imports import numpy as np
 
 from pymedphys._data import download
+
 from pymedphys._experimental.paulking.sinogram import (
     crop,
     find_modulation_factor,
